@@ -18,6 +18,7 @@ sub call{
     my $notice_limit = $data->{notice_limit} || 8;
     my $warn_limit = $data->{warn_limit} || 10;
     my $ban_limit = $data->{ban_limit} || 12;
+    my $ban_time = $data->{ban_time} || 1200;
     my $is_need_at = defined $data->{is_need_at}?$data->{is_need_at}:1;
 
     my $counter = $client->new_counter(id=>'SmartReply',period=>$data->{period} || 600);
@@ -43,7 +44,7 @@ sub call{
                 $ban{$msg->sender->id} = 1;
                 $client->reply_message($msg,"\@$sender_nick " . "您已被列入黑名单，$ban_time秒内提问无视",sub{$_[1]->msg_from("bot")});
                 $counter->clear($msg->group->gid ."|" .$msg->sender->id);
-                $client->timer($data->{ban_time} || 1200,sub{delete $ban{$msg->sender->id};});
+                $client->timer($ban_time ,sub{delete $ban{$msg->sender->id};});
                 return;
             }
             if($is_need_at and $limit >= $warn_limit){
@@ -64,14 +65,14 @@ sub call{
         $input=~s/\@\Q$user_nick\E ?|\[[^\[\]]+\]\x01|\[[^\[\]]+\]//g;
         return unless $input;
 
-        my @query_string = (
-            "key"       =>  $data->{apikey} || "4c53b48522ac4efdfe5dfb4f6149ae51",
+        my $json = {
+            "key"       =>  $data->{apikey} || "f771372ffd054183bfcdf260d7c7ad5a",
             "userid"    =>  $msg->sender->id,
             "info"      =>  decode("utf8",$input),
-        );
+        };
 
-        push @query_string,(loc=>$msg->sender->city."市") if $msg->type eq "group_message" and  $msg->sender->city; 
-        $client->http_get($api,{json=>1},form=>{@query_string},sub{
+        $json->{"loc"} = decode("utf8",$msg->sender->city) if $msg->type eq "group_message" and  $msg->sender->city; 
+        $client->http_post($api,{json=>1},json=>$json,sub{
             my $json = shift;
             return unless defined $json;
             return if $json->{code}=~/^4000[1-7]$/;
